"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AvatarListing = void 0;
const tslib_1 = require("tslib");
const ethers_1 = require("ethers");
const typechain_1 = require("@motif-foundation/listing/dist/typechain");
const _1_json_1 = (0, tslib_1.__importDefault)(require("@motif-foundation/listing/dist/addresses/1.json"));
const _3_json_1 = (0, tslib_1.__importDefault)(require("@motif-foundation/listing/dist/addresses/3.json"));
const _7018_json_1 = (0, tslib_1.__importDefault)(require("@motif-foundation/listing/dist/addresses/7018.json"));
const _7019_json_1 = (0, tslib_1.__importDefault)(require("@motif-foundation/listing/dist/addresses/7019.json"));
const addresses_1 = require("./addresses");
const utils_1 = require("./utils");
const avatarListingAddresses = {
    mainnet: _1_json_1.default.avatarListing,
    ropsten: _3_json_1.default.avatarListing,
    motif: _7018_json_1.default.avatarListing,
    motifTestnet: _7019_json_1.default.avatarListing,
};
class AvatarListing {
    constructor(signerOrProvider, chainId, avatarAddress) {
        this.chainId = chainId;
        this.readOnly = !ethers_1.Signer.isSigner(signerOrProvider);
        this.signerOrProvider = signerOrProvider;
        const network = (0, utils_1.chainIdToNetworkName)(chainId);
        const address = avatarListingAddresses[network];
        this.avatarListing = typechain_1.AvatarListing__factory.connect(address, signerOrProvider);
        if (avatarAddress) {
            const parsedAvatarAddress = (0, utils_1.validateAndParseAddress)(avatarAddress);
            this.avatarAddress = parsedAvatarAddress;
        }
        else {
            this.avatarAddress = addresses_1.addresses[network].avatar;
        }
    }
    fetchListing(listingId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.avatarListing.listings(listingId);
        });
    }
    fetchListingFromTransactionReceipt(receipt) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            for (const log of receipt.logs) {
                const description = this.avatarListing.interface.parseLog(log);
                if (description.args.listingId && log.address === this.avatarListing.address) {
                    return this.fetchListing(description.args.listingId);
                }
            }
            return null;
        });
    }
    createListing(tokenId, startsAt, duration, listPrice, listType, intermediary, intermediaryFeePercentages, listCurrency, tokenAddress = this.avatarAddress) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.avatarListing.createListing(tokenId, tokenAddress, startsAt, duration, listPrice, listType, intermediary, intermediaryFeePercentages, listCurrency);
        });
    }
    setListingApproval(listingId, approved) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.avatarListing.setListingApproval(listingId, approved);
        });
    }
    setListingDropApproval(listingId, approved, startsAt) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.avatarListing.setListingDropApproval(listingId, approved, startsAt);
        });
    }
    setListingListPrice(listingId, listPrice) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.avatarListing.setListingListPrice(listingId, listPrice);
        });
    }
    createBid(listingId, amount) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const { listCurrency } = yield this.avatarListing.listings(listingId);
            // If ETH listing, include the ETH in this transaction
            if (listCurrency === ethers_1.ethers.constants.AddressZero) {
                return this.avatarListing.createBid(listingId, amount, { value: amount });
            }
            else {
                return this.avatarListing.createBid(listingId, amount);
            }
        });
    }
    endFixedPriceListing(listingId, amount) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const { listCurrency } = yield this.avatarListing.listings(listingId);
            if (listCurrency === ethers_1.ethers.constants.AddressZero) {
                return this.avatarListing.endFixedPriceListing(listingId, amount, { value: amount });
            }
            else {
                return this.avatarListing.endFixedPriceListing(listingId, amount);
            }
        });
    }
    endListing(listingId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.avatarListing.endListing(listingId);
        });
    }
    cancelListing(listingId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.avatarListing.cancelListing(listingId);
        });
    }
}
exports.AvatarListing = AvatarListing;
//# sourceMappingURL=AvatarListing.js.map