"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LandListing = void 0;
const tslib_1 = require("tslib");
const ethers_1 = require("ethers");
const typechain_1 = require("@motif-foundation/listing/dist/typechain");
const _1_json_1 = (0, tslib_1.__importDefault)(require("@motif-foundation/listing/dist/addresses/1.json"));
const _3_json_1 = (0, tslib_1.__importDefault)(require("@motif-foundation/listing/dist/addresses/3.json"));
const _7018_json_1 = (0, tslib_1.__importDefault)(require("@motif-foundation/listing/dist/addresses/7018.json"));
const _7019_json_1 = (0, tslib_1.__importDefault)(require("@motif-foundation/listing/dist/addresses/7019.json"));
const addresses_1 = require("./addresses");
const utils_1 = require("./utils");
const landListingAddresses = {
    mainnet: _1_json_1.default.landListing,
    ropsten: _3_json_1.default.landListing,
    motif: _7018_json_1.default.landListing,
    motifTestnet: _7019_json_1.default.landListing,
};
class LandListing {
    constructor(signerOrProvider, chainId, landAddress) {
        this.chainId = chainId;
        this.readOnly = !ethers_1.Signer.isSigner(signerOrProvider);
        this.signerOrProvider = signerOrProvider;
        const network = (0, utils_1.chainIdToNetworkName)(chainId);
        const address = landListingAddresses[network];
        this.landListing = typechain_1.LandListing__factory.connect(address, signerOrProvider);
        if (landAddress) {
            const parsedLandAddress = (0, utils_1.validateAndParseAddress)(landAddress);
            this.landAddress = parsedLandAddress;
        }
        else {
            this.landAddress = addresses_1.addresses[network].land;
        }
    }
    fetchListing(listingId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.landListing.listings(listingId);
        });
    }
    fetchListingFromTransactionReceipt(receipt) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            for (const log of receipt.logs) {
                const description = this.landListing.interface.parseLog(log);
                if (description.args.listingId && log.address === this.landListing.address) {
                    return this.fetchListing(description.args.listingId);
                }
            }
            return null;
        });
    }
    createListing(tokenId, startsAt, duration, listPrice, listType, intermediary, intermediaryFeePercentages, listCurrency, tokenAddress = this.landAddress) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.landListing.createListing(tokenId, tokenAddress, startsAt, duration, listPrice, listType, intermediary, intermediaryFeePercentages, listCurrency);
        });
    }
    setListingApproval(listingId, approved) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.landListing.setListingApproval(listingId, approved);
        });
    }
    setListingDropApproval(listingId, approved, startsAt) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.landListing.setListingDropApproval(listingId, approved, startsAt);
        });
    }
    setListingListPrice(listingId, listPrice) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.landListing.setListingListPrice(listingId, listPrice);
        });
    }
    createBid(listingId, amount) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const { listCurrency } = yield this.landListing.listings(listingId);
            // If ETH listing, include the ETH in this transaction
            if (listCurrency === ethers_1.ethers.constants.AddressZero) {
                return this.landListing.createBid(listingId, amount, { value: amount });
            }
            else {
                return this.landListing.createBid(listingId, amount);
            }
        });
    }
    endFixedPriceListing(listingId, amount) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const { listCurrency } = yield this.landListing.listings(listingId);
            if (listCurrency === ethers_1.ethers.constants.AddressZero) {
                return this.landListing.endFixedPriceListing(listingId, amount, { value: amount });
            }
            else {
                return this.landListing.endFixedPriceListing(listingId, amount);
            }
        });
    }
    endListing(listingId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.landListing.endListing(listingId);
        });
    }
    cancelListing(listingId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.landListing.cancelListing(listingId);
        });
    }
}
exports.LandListing = LandListing;
//# sourceMappingURL=LandListing.js.map