"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SpaceListing = void 0;
const tslib_1 = require("tslib");
const ethers_1 = require("ethers");
const typechain_1 = require("@motif-foundation/listing/dist/typechain");
const _1_json_1 = (0, tslib_1.__importDefault)(require("@motif-foundation/listing/dist/addresses/1.json"));
const _3_json_1 = (0, tslib_1.__importDefault)(require("@motif-foundation/listing/dist/addresses/3.json"));
const _7018_json_1 = (0, tslib_1.__importDefault)(require("@motif-foundation/listing/dist/addresses/7018.json"));
const _7019_json_1 = (0, tslib_1.__importDefault)(require("@motif-foundation/listing/dist/addresses/7019.json"));
const addresses_1 = require("./addresses");
const utils_1 = require("./utils");
const spaceListingAddresses = {
    mainnet: _1_json_1.default.spaceListing,
    ropsten: _3_json_1.default.spaceListing,
    motif: _7018_json_1.default.spaceListing,
    motifTestnet: _7019_json_1.default.spaceListing,
};
class SpaceListing {
    constructor(signerOrProvider, chainId, spaceAddress) {
        this.chainId = chainId;
        this.readOnly = !ethers_1.Signer.isSigner(signerOrProvider);
        this.signerOrProvider = signerOrProvider;
        const network = (0, utils_1.chainIdToNetworkName)(chainId);
        const address = spaceListingAddresses[network];
        this.spaceListing = typechain_1.SpaceListing__factory.connect(address, signerOrProvider);
        if (spaceAddress) {
            const parsedSpaceAddress = (0, utils_1.validateAndParseAddress)(spaceAddress);
            this.spaceAddress = parsedSpaceAddress;
        }
        else {
            this.spaceAddress = addresses_1.addresses[network].space;
        }
    }
    fetchListing(listingId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.spaceListing.listings(listingId);
        });
    }
    fetchListingFromTransactionReceipt(receipt) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            for (const log of receipt.logs) {
                const description = this.spaceListing.interface.parseLog(log);
                if (description.args.listingId && log.address === this.spaceListing.address) {
                    return this.fetchListing(description.args.listingId);
                }
            }
            return null;
        });
    }
    createListing(tokenId, startsAt, duration, listPrice, listType, intermediary, intermediaryFeePercentages, listCurrency, tokenAddress = this.spaceAddress) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.spaceListing.createListing(tokenId, tokenAddress, startsAt, duration, listPrice, listType, intermediary, intermediaryFeePercentages, listCurrency);
        });
    }
    setListingApproval(listingId, approved) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.spaceListing.setListingApproval(listingId, approved);
        });
    }
    setListingDropApproval(listingId, approved, startsAt) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.spaceListing.setListingDropApproval(listingId, approved, startsAt);
        });
    }
    setListingListPrice(listingId, listPrice) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.spaceListing.setListingListPrice(listingId, listPrice);
        });
    }
    createBid(listingId, amount) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const { listCurrency } = yield this.spaceListing.listings(listingId);
            // If ETH listing, include the ETH in this transaction
            if (listCurrency === ethers_1.ethers.constants.AddressZero) {
                return this.spaceListing.createBid(listingId, amount, { value: amount });
            }
            else {
                return this.spaceListing.createBid(listingId, amount);
            }
        });
    }
    endFixedPriceListing(listingId, amount) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const { listCurrency } = yield this.spaceListing.listings(listingId);
            if (listCurrency === ethers_1.ethers.constants.AddressZero) {
                return this.spaceListing.endFixedPriceListing(listingId, amount, { value: amount });
            }
            else {
                return this.spaceListing.endFixedPriceListing(listingId, amount);
            }
        });
    }
    endListing(listingId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.spaceListing.endListing(listingId);
        });
    }
    cancelListing(listingId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.spaceListing.cancelListing(listingId);
        });
    }
}
exports.SpaceListing = SpaceListing;
//# sourceMappingURL=SpaceListing.js.map